package com.yunfeiyun.agmp.fms.service;

import com.yunfeiyun.agmp.common.core.domain.AjaxResult;
import com.yunfeiyun.agmp.fms.domain.MppTask;
import com.yunfeiyun.agmp.fms.domain.reqvo.AddMppTaskReqVo;

import java.util.List;

/**
 * 农产品生产任务Service接口
 * 
 * @author 杨晓辉
 * @date 2023-07-03
 */
public interface IMppTaskService 
{
    /**
     * 查询农产品生产任务
     * 
     * @param taskId 农产品生产任务主键
     * @return 农产品生产任务
     */
    public MppTask selectMppTaskByTaskId(String taskId);

    /**
     * 查询农产品生产任务列表
     * 
     * @param mppTask 农产品生产任务
     * @return 农产品生产任务集合
     */
    public List<MppTask> selectMppTaskList(MppTask mppTask);

    /**
     * 新增农产品生产任务
     * 
     * @param mppTask 农产品生产任务
     * @return 结果
     */
    public AjaxResult insertMppTask(AddMppTaskReqVo reqVo);

    /**
     * 修改农产品生产任务
     * 
     * @param mppTask 农产品生产任务
     * @return 结果
     */
    public int updateMppTask(MppTask mppTask);

    /**
     * 批量删除农产品生产任务
     * 
     * @param taskIds 需要删除的农产品生产任务主键集合
     * @return 结果
     */
    public int deleteMppTaskByTaskIds(String[] taskIds);

    /**
     * 删除农产品生产任务信息
     * 
     * @param taskId 农产品生产任务主键
     * @return 结果
     */
    public int deleteMppTaskByTaskId(String taskId);
}
